/**
 * The input type is string or undefined.
 *
 * Unlike core.getInput, we return undefined when the environment variable isn't provided.
 *
 * @see getInput
 */
export type Input = string | undefined;
/**
 * Returns the value of the input, as found in the environment.
 *
 * This function parses the environment the same as core.getInput(). However, core.getInput()
 * returns an empty string when the environment variable isn't defined. The GitHub Actions engine does the
 * same when no value is provided.
 *
 * This function uses a different approach. It returns undefined if the input is not set in the environment,
 * *or if the environment variable is an empty string*. This can make it easier to set default values
 * using validation frameworks.
 *
 * @param name - The input name.
 */
export declare function getInput(name: string): Input;
/**
 * Typesafe object when getting multiple inputs at once.
 */
export type GetInputsResult<I> = {
    [K in keyof I]: Input;
};
/**
 * Gets a set of inputs and returns their values in a typesafe object.
 *
 * @param inputs - The inputs to parse from the environment.
 */
export declare function getInputs<I>(...inputs: Array<keyof I>): GetInputsResult<I>;
/**
 * Parses the Github Actions outputs from the provided file as written by the core.setOutput
 * utility.
 *
 * The core.setOutput utility stores the outputs as heredocs with randomly generated delimiters.
 * This function parses those out and returns the remaining key value pairs as an object.
 *
 * If a key is provided more than once, the last value takes precedence.
 *
 * @param filePath - The outputs file path. Defaults to GITHUB_OUTPUT. Throws if neither the
 *  parameter and the environment variable are provided.
 *
 * @return The outputs as a record of string.
 */
export declare function parseOutputs(filePath?: string): Promise<Record<string, string>>;
/**
 * This function does away with the common boilerplate code related to running a GitHub Actions
 * handler.
 *
 * It wraps the whole process with convenient debug statements that are turned on
 * by setting ACTIONS_STEP_DEBUG to true.
 *
 * The handler can return outputs and those are forwarded automatically to core.setOutput at the
 * end of the run. core.setOutput JSON stringifies everything.
 *
 * Any runtime errors occurring during this function's execution results in a call to core.setFailed.
 *
 * @param handler - The GitHub Actions handler.
 *
 * @see https://docs.github.com/en/actions/monitoring-and-troubleshooting-workflows/enabling-debug-logging
 */
export declare function runActionHandler(handler: () => Promise<unknown>): void;
